/* -- AIX/6000 System monitor 
**
**     print_top.h
**
** Copyright (c) 1991-1995 Jussi Maki, All Rights Reserved.
** Copyright (c) 1993-2001 Marcel Mol, All Rights Reserved.
** NON-COMMERCIAL USE ALLOWED. YOU ARE FREE TO DISTRIBUTE
** THIS PROGRAM AND MODIFY IT AS LONG AS YOU KEEP ORIGINAL
** COPYRIGHTS.
*/

void calc_top(double refresh_time, topcpu_t *top, int nproc);
void print_topcpu(double refresh_time, topcpu_t *top, int ntop,
                  time_t now, int y, int cpu_cnt);
void log_top_header();
void log_top(double refresh_time, topcpu_t *top, int nproc);
void log_top_max();
void max_top_init();
